@@ -69,7 +69,7 @@ def read_json(file_path):
     res = []
     for line in d:
         try:
-            res.append(json.loads(i))
+            res.append(json.loads(line))
         except:
             continue
     print('all {} lines, success {} lines'.format(len(d), len(res)))
@@ -81,6 +81,15 @@ def write_json(file_path, dat, mode='a'):
         for i in dat:
             f.write(json.dumps(i, ensure_ascii=False) + '\n')
 
+def read_pkl(file_path)
+    import pickle 
+    return pickle.loads(open(file_path, 'rb').read())
+
+def write_pkl(file_path, d):
+    import pickle
+    with open(file_path, 'wb') as f:
+        f.write(pickle.dumps(d))
+
 
 def get_resolution(resolution):
     resolutions = [('16:9', 16./9), ('4:3', 4./3), ('1:1', 1), ('3:4', 3./4), ('9:16', 9./16)]
@@ -100,6 +109,10 @@ d = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'map.pkl')
 
 en2ch = pickle.loads(open(d, 'rb').read())
 def translate_tag(tag):
-    return en2ch.get(tag, tag)
-
-
+    if tag in en2ch:
+        return en2ch[tag]
+    elif tag.replace('_', ' ') in en2ch:
+        return en2ch[tag.replace('_', ' ')]
+    elif tag.replace(' ', '_') in en2ch:
+        return en2ch[tag.replace(' ', '_')]
+    return tag
